@@ -1,7 +1,6 @@
-"predprob.zeroinfl" <-
-function(obj,...){
+predprob.zeroinfl <- function(obj, ...){
     if(!inherits(obj,"zeroinfl"))
         stop("predprob.zeroinfl only available for zeroinfl objects\n")
-    predict.zeroinfl(obj,type="prob",...)$prob
+    predict.zeroinfl(obj, type="prob", ...)$prob
 }
 
